==> sitegen-0.26.0.tgz: package/lib/loader/boot.js <==
'use strict';

var _babelTypes = require('babel-types');

var _babelGenerator = require('babel-generator');

var _babelGenerator2 = _interopRequireDefault(_babelGenerator);

var _RouteCompiler = require('../routing/RouteCompiler');

var _RouteCompiler2 = _interopRequireDefault(_RouteCompiler);

var _Route = require('../routing/Route');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var __liftToAST = require('/Users/andreypopp/Workspace/sitegen/node_modules/.store/babel-plugin-ast-literal@0.5.3/_/lib/liftToAST.js').default; /**
                                                                                                                                                 * @copyright 2016-present, Sitegen team
                                                                                                                                                 */

var BOOT_MODULE = require.resolve('../boot');
var META_MODULE = require.resolve('react-helmet');
var SITE_MODULE = require.resolve('../Site');

module.exports = function bootLoader(_source) {
  var _this = this;

  this.cacheable();

  var compiler = this._compiler;
  var publicPath = compiler.options.output.publicPath;
  var cb = this.async();
  var fs = compiler.inputFileSystem;

  var route = compiler.options.site.route;

  // traverse route tree and set watchers on collections
  // TODO: make sure we stay consistent with what renderRoute(..) does

  (0, _Route.forEach)(route, function (route) {
    if (route.collection) {
      _this.addContextDependency(route.collection.page.directory);
    }
  });

  var split = compiler.options.env === 'production' ? undefined : false;
  var routeCompiler = new _RouteCompiler2.default({ fs: fs, split: split, publicPath: publicPath });
  routeCompiler.render(route).then(function (route) {
    return (0, _babelGenerator2.default)((0, _babelTypes.program)(function (_param, _param2, _param3, _param4) {
      _param = __liftToAST(_param);
      _param2 = __liftToAST(_param2);
      _param3 = __liftToAST(_param3);
      _param4 = __liftToAST(_param4);
      return [{
        "type": "VariableDeclaration",
        "declarations": [{
          "type": "VariableDeclarator",
          "id": {
            "type": "Identifier",
            "name": "makeDebug"
          },
          "init": {
            "type": "CallExpression",
            "callee": {
              "type": "Identifier",
              "name": "require"
            },
            "arguments": [{
              "type": "StringLiteral",
              "extra": {
                "rawValue": "debug",
                "raw": "'debug'"
              },
              "value": "debug"
            }]
          }
        }],
        "kind": "var"
      }, {
        "type": "VariableDeclaration",
        "declarations": [{
          "type": "VariableDeclarator",
          "id": {
            "type": "Identifier",
            "name": "React"
          },
          "init": {
            "type": "CallExpression",
            "callee": {
              "type": "Identifier",
              "name": "require"
            },
            "arguments": [{
              "type": "StringLiteral",
              "extra": {
                "rawValue": "react",
                "raw": "'react'"
              },
              "value": "react"
            }]
          }
        }],
        "kind": "var"
      }, {
        "type": "VariableDeclaration",
        "declarations": [{
          "type": "VariableDeclarator",
          "id": {
            "type": "Identifier",
            "name": "boot"
          },
          "init": {
            "type": "MemberExpression",
            "object": {
              "type": "CallExpression",
              "callee": {
                "type": "Identifier",
                "name": "require"
              },
              "arguments": [_param]
            },
            "property": {
              "type": "Identifier",
              "name": "boot"
            },
            "computed": false
          }
        }],
        "kind": "var"
      }, {
        "type": "VariableDeclaration",
        "declarations": [{
          "type": "VariableDeclarator",
          "id": {
            "type": "Identifier",
            "name": "debug"
          },
          "init": {
            "type": "CallExpression",
            "callee": {
              "type": "Identifier",
              "name": "makeDebug"
            },
            "arguments": [{
              "type": "StringLiteral",
              "extra": {
                "rawValue": "sitegen:runtime:route",
                "raw": "'sitegen:runtime:route'"
              },
              "value": "sitegen:runtime:route"
            }]
          }
        }],
        "kind": "var"
      }, {
        "type": "ExpressionStatement",
        "expression": {
          "type": "AssignmentExpression",
          "operator": "=",
          "left": {
            "type": "MemberExpression",
            "object": {
              "type": "Identifier",
              "name": "exports"
            },
            "property": {
              "type": "Identifier",
              "name": "route"
            },
            "computed": false
          },
          "right": _param2
        }
      }, {
        "type": "ExpressionStatement",
        "expression": {
          "type": "AssignmentExpression",
          "operator": "=",
          "left": {
            "type": "MemberExpression",
            "object": {
              "type": "Identifier",
              "name": "exports"
            },
            "property": {
              "type": "Identifier",
              "name": "Meta"
            },
            "computed": false
          },
          "right": {
            "type": "CallExpression",
            "callee": {
              "type": "Identifier",
              "name": "require"
            },
            "arguments": [_param3]
          }
        }
      }, {
        "type": "ExpressionStatement",
        "expression": {
          "type": "AssignmentExpression",
          "operator": "=",
          "left": {
            "type": "MemberExpression",
            "object": {
              "type": "Identifier",
              "name": "exports"
            },
            "property": {
              "type": "Identifier",
              "name": "Site"
            },
            "computed": false
          },
          "right": {
            "type": "MemberExpression",
            "object": {
              "type": "CallExpression",
              "callee": {
                "type": "Identifier",
                "name": "require"
              },
              "arguments": [_param4]
            },
            "property": {
              "type": "Identifier",
              "name": "default"
            },
            "computed": false
          }
        }
      }, {
        "type": "ExpressionStatement",
        "expression": {
          "type": "AssignmentExpression",
          "operator": "=",
          "left": {
            "type": "MemberExpression",
            "object": {
              "type": "Identifier",
              "name": "exports"
            },
            "property": {
              "type": "Identifier",
              "name": "React"
            },
            "computed": false
          },
          "right": {
            "type": "Identifier",
            "name": "React"
          }
        }
      }, {
        "type": "IfStatement",
        "test": {
          "type": "BinaryExpression",
          "left": {
            "type": "UnaryExpression",
            "operator": "typeof",
            "prefix": true,
            "extra": {
              "parenthesizedArgument": false
            },
            "argument": {
              "type": "Identifier",
              "name": "window"
            }
          },
          "operator": "!==",
          "right": {
            "type": "StringLiteral",
            "extra": {
              "rawValue": "undefined",
              "raw": "'undefined'"
            },
            "value": "undefined"
          }
        },
        "consequent": {
          "type": "BlockStatement",
          "body": [{
            "type": "IfStatement",
            "test": {
              "type": "MemberExpression",
              "object": {
                "type": "Identifier",
                "name": "module"
              },
              "property": {
                "type": "Identifier",
                "name": "hot"
              },
              "computed": false
            },
            "consequent": {
              "type": "BlockStatement",
              "body": [{
                "type": "ExpressionStatement",
                "expression": {
                  "type": "CallExpression",
                  "callee": {
                    "type": "MemberExpression",
                    "object": {
                      "type": "MemberExpression",
                      "object": {
                        "type": "Identifier",
                        "name": "module"
                      },
                      "property": {
                        "type": "Identifier",
                        "name": "hot"
                      },
                      "computed": false
                    },
                    "property": {
                      "type": "Identifier",
                      "name": "accept"
                    },
                    "computed": false
                  },
                  "arguments": []
                }
              }],
              "directives": []
            },
            "alternate": null
          }, {
            "type": "ExpressionStatement",
            "expression": {
              "type": "CallExpression",
              "callee": {
                "type": "Identifier",
                "name": "boot"
              },
              "arguments": [{
                "type": "MemberExpression",
                "object": {
                  "type": "Identifier",
                  "name": "exports"
                },
                "property": {
                  "type": "Identifier",
                  "name": "route"
                },
                "computed": false
              }]
            }
          }],
          "directives": []
        },
        "alternate": null
      }];
    }((0, _babelTypes.stringLiteral)(BOOT_MODULE), route, (0, _babelTypes.stringLiteral)(META_MODULE), (0, _babelTypes.stringLiteral)(SITE_MODULE)))).code;
  }).then(function (code) {
    return cb(null, code);
  }, function (err) {
    return cb(err);
  });
};

==> sitegen-0.27.2.tgz: package/lib/loader/boot.js <==
'use strict';

var _babelTypes = require('babel-types');

var _babelGenerator = require('babel-generator');

var _babelGenerator2 = _interopRequireDefault(_babelGenerator);

var _RouteCompiler = require('../routing/RouteCompiler');

var _RouteCompiler2 = _interopRequireDefault(_RouteCompiler);

var _Route = require('../routing/Route');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var __liftToAST = require('babel-plugin-ast-literal/lib/liftToAST').default; /**
                                                                              * @copyright 2016-present, Sitegen team
                                                                              */

var BOOT_MODULE = require.resolve('../boot');
var META_MODULE = require.resolve('react-helmet');
var SITE_MODULE = require.resolve('../Site');

module.exports = function bootLoader(_source) {
  var _this = this;

  this.cacheable();

  var compiler = this._compiler;
  var publicPath = compiler.options.output.publicPath;
  var cb = this.async();
  var fs = compiler.inputFileSystem;

  var route = compiler.options.site.route;

  // traverse route tree and set watchers on collections
  // TODO: make sure we stay consistent with what renderRoute(..) does

  (0, _Route.forEach)(route, function (route) {
    if (route.collection) {
      _this.addContextDependency(route.collection.page.directory);
    }
  });

  var split = compiler.options.env === 'production' ? undefined : false;
  var routeCompiler = new _RouteCompiler2.default({ fs: fs, split: split, publicPath: publicPath });
  routeCompiler.render(route).then(function (route) {
    return (0, _babelGenerator2.default)((0, _babelTypes.program)(function (_param, _param2, _param3, _param4) {
      _param = __liftToAST(_param);
      _param2 = __liftToAST(_param2);
      _param3 = __liftToAST(_param3);
      _param4 = __liftToAST(_param4);
      return [{
        "type": "VariableDeclaration",
        "declarations": [{
          "type": "VariableDeclarator",
          "id": {
            "type": "Identifier",
            "name": "makeDebug"
          },
          "init": {
            "type": "CallExpression",
            "callee": {
              "type": "Identifier",
              "name": "require"
            },
            "arguments": [{
              "type": "StringLiteral",
              "extra": {
                "rawValue": "debug",
                "raw": "'debug'"
              },
              "value": "debug"
            }]
          }
        }],
        "kind": "var"
      }, {
        "type": "VariableDeclaration",
        "declarations": [{
          "type": "VariableDeclarator",
          "id": {
            "type": "Identifier",
            "name": "React"
          },
          "init": {
            "type": "CallExpression",
            "callee": {
              "type": "Identifier",
              "name": "require"
            },
            "arguments": [{
              "type": "StringLiteral",
              "extra": {
                "rawValue": "react",
                "raw": "'react'"
              },
              "value": "react"
            }]
          }
        }],
        "kind": "var"
      }, {
        "type": "VariableDeclaration",
        "declarations": [{
          "type": "VariableDeclarator",
          "id": {
            "type": "Identifier",
            "name": "boot"
          },
          "init": {
            "type": "MemberExpression",
            "object": {
              "type": "CallExpression",
              "callee": {
                "type": "Identifier",
                "name": "require"
              },
              "arguments": [_param]
            },
            "property": {
              "type": "Identifier",
              "name": "boot"
            },
            "computed": false
          }
        }],
        "kind": "var"
      }, {
        "type": "VariableDeclaration",
        "declarations": [{
          "type": "VariableDeclarator",
          "id": {
            "type": "Identifier",
            "name": "debug"
          },
          "init": {
            "type": "CallExpression",
            "callee": {
              "type": "Identifier",
              "name": "makeDebug"
            },
            "arguments": [{
              "type": "StringLiteral",
              "extra": {
                "rawValue": "sitegen:runtime:route",
                "raw": "'sitegen:runtime:route'"
              },
              "value": "sitegen:runtime:route"
            }]
          }
        }],
        "kind": "var"
      }, {
        "type": "ExpressionStatement",
        "expression": {
          "type": "AssignmentExpression",
          "operator": "=",
          "left": {
            "type": "MemberExpression",
            "object": {
              "type": "Identifier",
              "name": "exports"
            },
            "property": {
              "type": "Identifier",
              "name": "route"
            },
            "computed": false
          },
          "right": _param2
        }
      }, {
        "type": "ExpressionStatement",
        "expression": {
          "type": "AssignmentExpression",
          "operator": "=",
          "left": {
            "type": "MemberExpression",
            "object": {
              "type": "Identifier",
              "name": "exports"
            },
            "property": {
              "type": "Identifier",
              "name": "Meta"
            },
            "computed": false
          },
          "right": {
            "type": "CallExpression",
            "callee": {
              "type": "Identifier",
              "name": "require"
            },
            "arguments": [_param3]
          }
        }
      }, {
        "type": "ExpressionStatement",
        "expression": {
          "type": "AssignmentExpression",
          "operator": "=",
          "left": {
            "type": "MemberExpression",
            "object": {
              "type": "Identifier",
              "name": "exports"
            },
            "property": {
              "type": "Identifier",
              "name": "Site"
            },
            "computed": false
          },
          "right": {
            "type": "MemberExpression",
            "object": {
              "type": "CallExpression",
              "callee": {
                "type": "Identifier",
                "name": "require"
              },
              "arguments": [_param4]
            },
            "property": {
              "type": "Identifier",
              "name": "default"
            },
            "computed": false
          }
        }
      }, {
        "type": "ExpressionStatement",
        "expression": {
          "type": "AssignmentExpression",
          "operator": "=",
          "left": {
            "type": "MemberExpression",
            "object": {
              "type": "Identifier",
              "name": "exports"
            },
            "property": {
              "type": "Identifier",
              "name": "React"
            },
            "computed": false
          },
          "right": {
            "type": "Identifier",
            "name": "React"
          }
        }
      }, {
        "type": "IfStatement",
        "test": {
          "type": "BinaryExpression",
          "left": {
            "type": "UnaryExpression",
            "operator": "typeof",
            "prefix": true,
            "extra": {
              "parenthesizedArgument": false
            },
            "argument": {
              "type": "Identifier",
              "name": "window"
            }
          },
          "operator": "!==",
          "right": {
            "type": "StringLiteral",
            "extra": {
              "rawValue": "undefined",
              "raw": "'undefined'"
            },
            "value": "undefined"
          }
        },
        "consequent": {
          "type": "BlockStatement",
          "body": [{
            "type": "IfStatement",
            "test": {
              "type": "MemberExpression",
              "object": {
                "type": "Identifier",
                "name": "module"
              },
              "property": {
                "type": "Identifier",
                "name": "hot"
              },
              "computed": false
            },
            "consequent": {
              "type": "BlockStatement",
              "body": [{
                "type": "ExpressionStatement",
                "expression": {
                  "type": "CallExpression",
                  "callee": {
                    "type": "MemberExpression",
                    "object": {
                      "type": "MemberExpression",
                      "object": {
                        "type": "Identifier",
                        "name": "module"
                      },
                      "property": {
                        "type": "Identifier",
                        "name": "hot"
                      },
                      "computed": false
                    },
                    "property": {
                      "type": "Identifier",
                      "name": "accept"
                    },
                    "computed": false
                  },
                  "arguments": []
                }
              }],
              "directives": []
            },
            "alternate": null
          }, {
            "type": "ExpressionStatement",
            "expression": {
              "type": "CallExpression",
              "callee": {
                "type": "Identifier",
                "name": "boot"
              },
              "arguments": [{
                "type": "MemberExpression",
                "object": {
                  "type": "Identifier",
                  "name": "exports"
                },
                "property": {
                  "type": "Identifier",
                  "name": "route"
                },
                "computed": false
              }]
            }
          }],
          "directives": []
        },
        "alternate": null
      }];
    }((0, _babelTypes.stringLiteral)(BOOT_MODULE), route, (0, _babelTypes.stringLiteral)(META_MODULE), (0, _babelTypes.stringLiteral)(SITE_MODULE)))).code;
  }).then(function (code) {
    return cb(null, code);
  }, function (err) {
    return cb(err);
  });
};
